nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Csl

Struct Csl 

#[repr(transparent)]
pub struct Csl(pub u32);
Config security level register

Tuple Fields

0: u32

Implementations

Source

impl Csl

pub const fn sur_s2(&self) -> SurS2

Secure user read access control for the second slave

pub const fn set_sur_s2(&mut self, val: SurS2)

Secure user read access control for the second slave

pub const fn ssr_s2(&self) -> SsrS2

Secure supervisor read access control for the second slave

pub const fn set_ssr_s2(&mut self, val: SsrS2)

Secure supervisor read access control for the second slave

pub const fn nur_s2(&self) -> NurS2

Non-secure user read access control for the second slave

pub const fn set_nur_s2(&mut self, val: NurS2)

Non-secure user read access control for the second slave

pub const fn nsr_s2(&self) -> NsrS2

Non-secure supervisor read access control for the second slave

pub const fn set_nsr_s2(&mut self, val: NsrS2)

Non-secure supervisor read access control for the second slave

pub const fn suw_s2(&self) -> SuwS2

Secure user write access control for the second slave

pub const fn set_suw_s2(&mut self, val: SuwS2)

Secure user write access control for the second slave

pub const fn ssw_s2(&self) -> SswS2

Secure supervisor write access control for the second slave

pub const fn set_ssw_s2(&mut self, val: SswS2)

Secure supervisor write access control for the second slave

pub const fn nuw_s2(&self) -> NuwS2

Non-secure user write access control for the second slave

pub const fn set_nuw_s2(&mut self, val: NuwS2)

Non-secure user write access control for the second slave

pub const fn nsw_s2(&self) -> NswS2

Non-secure supervisor write access control for the second slave

pub const fn set_nsw_s2(&mut self, val: NswS2)

Non-secure supervisor write access control for the second slave

pub const fn lock_s2(&self) -> LockS2

The lock bit corresponding to the second slave. It is written by the secure software.

pub const fn set_lock_s2(&mut self, val: LockS2)

The lock bit corresponding to the second slave. It is written by the secure software.

pub const fn sur_s1(&self) -> SurS1

Secure user read access control for the first slave

pub const fn set_sur_s1(&mut self, val: SurS1)

Secure user read access control for the first slave

pub const fn ssr_s1(&self) -> SsrS1

Secure supervisor read access control for the first slave

pub const fn set_ssr_s1(&mut self, val: SsrS1)

Secure supervisor read access control for the first slave

pub const fn nur_s1(&self) -> NurS1

Non-secure user read access control for the first slave

pub const fn set_nur_s1(&mut self, val: NurS1)

Non-secure user read access control for the first slave

pub const fn nsr_s1(&self) -> NsrS1

Non-secure supervisor read access control for the first slave

pub const fn set_nsr_s1(&mut self, val: NsrS1)

Non-secure supervisor read access control for the first slave

pub const fn suw_s1(&self) -> SuwS1

Secure user write access control for the first slave

pub const fn set_suw_s1(&mut self, val: SuwS1)

Secure user write access control for the first slave

pub const fn ssw_s1(&self) -> SswS1

Secure supervisor write access control for the first slave

pub const fn set_ssw_s1(&mut self, val: SswS1)

Secure supervisor write access control for the first slave

pub const fn nuw_s1(&self) -> NuwS1

Non-secure user write access control for the first slave

pub const fn set_nuw_s1(&mut self, val: NuwS1)

Non-secure user write access control for the first slave

pub const fn nsw_s1(&self) -> NswS1

Non-secure supervisor write access control for the first slave

pub const fn set_nsw_s1(&mut self, val: NswS1)

Non-secure supervisor write access control for the first slave

pub const fn lock_s1(&self) -> LockS1

The lock bit corresponding to the first slave. It is written by the secure software.

pub const fn set_lock_s1(&mut self, val: LockS1)

The lock bit corresponding to the first slave. It is written by the secure software.